@@ -1,5 +1,27 @@
 /*
- *	HEADER FILE FOR TWCLOCK
+ * twclock:  A world clock implemented with openMotif widgets
+ * Copyright (C) 1997-2020 Ted Williams - WA0EIR
+ *
+ * This file is part of twclock
+ *
+ * twclock is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have recieved a copy of the GNU General Public License
+ * along with this program. If not, see <http://gnu.org/licences/>.
+ *
+ * Versions: 3.5 -  Jan 2020
+ */
+
+/*
+ * twclock.h
  */
 
 #ifndef TWCLOCK_H_INCLUDED
@@ -105,26 +127,27 @@ typedef struct
    } AppRes;
 
 /*
- * Globals and Forward Declarations
+ * Forward Declarations
  */
-XtAppContext app;
-AppRes appRes;
+extern XtAppContext app;
+extern AppRes appRes;
 
-int    post_from;
-Widget clock_shell;
-Widget call_toggleB;
-Widget hr_scale;
-Widget min_scale;
-Widget sec_scale;
-Widget date_label;
+extern int    post_from;
+extern Widget clock_shell;
+extern Widget call_toggleB;
+extern Widget hr_scale;
+extern Widget min_scale;
+extern Widget sec_scale;
+extern Widget date_label;
+
+extern int doit;
+extern int count;
+extern int flashFlag;
+extern int cwIDdone;
+extern XtIntervalId alarm_id;
+extern XtIntervalId auto_id;
+extern XtIntervalId time_id;
 
-int doit;
-int count;
-int flashFlag;
-int cwIDdone;
-XtIntervalId alarm_id;
-XtIntervalId auto_id;
-XtIntervalId time_id;
 
 void build_widgets (void);
 void input_event (Widget, XtPointer, XEvent *, Boolean *);
@@ -147,7 +170,3 @@ void errCancelCB (Widget , XtPointer, XtPointer);
 void settimer (void);
 
 #endif
-
-
-
-
