@@ -1,10 +1,12 @@
 /*
- * twclockCB:  A world clock implemented with openMotif widgets
- * Copyright (C) 1997->2017 Ted Williams - WA0EIR
+ * twclock:  A world clock implemented with openMotif widgets
+ * Copyright (C) 1997-2020 Ted Williams - WA0EIR
  *
- * This program is free software; you can redistribute it and/or modify
+ * This file is part of twclock
+ *
+ * twclock is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,11 +15,9 @@
  * GNU General Public License for more details.
  *
  * You should have recieved a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge. MA 02139, USA.
- * See the COPYING file in this directory
+ * along with this program. If not, see <http://gnu.org/licences/>.
  *
- * Version: 3.4 - Jan 2017
+ * Versions: 3.5 -  Jan 2020
  */
 
 /*
@@ -214,13 +214,6 @@ void  gettime ()
    time (&current);
    timestruct = localtime (&current);   /* get localtime as per TZ */
 
-/****  TJW
-   makes time 12 hour clock, but needs to show AM/PM in GUI
-   if (timestruct->tm_hour > 13)
-      timestruct->tm_hour = timestruct->tm_hour - 12;
- ****/
-
-
    XtVaSetValues (hr_scale,  XmNvalue, timestruct->tm_hour, NULL);
    XtVaSetValues (min_scale, XmNvalue, timestruct->tm_min,  NULL);
    XtVaSetValues (sec_scale, XmNvalue, timestruct->tm_sec,  NULL);
@@ -401,38 +394,10 @@ void alarm_timer (void)
 
    /* should we beep? */
    if (appRes.beep == True)
-   {
-      /*
-       * This code was stolen from 
-       * http://agendawiki.com/cgi-bin/aw.pl?UnusualInputOutput
-       * and modified to restore the system default values.
-       */
-      XKeyboardControl v;
-      XKeyboardState save;
-      Display *xdisplay = XOpenDisplay(NULL);
-
-      /* Get the current keyboard control values so we can restore them */
-      XGetKeyboardControl (xdisplay, &save);
-
-      /* Set the desired pitch, duration, and volume (percent) level */
-      v.bell_pitch = 800;
-      v.bell_duration = 100;
-      v.bell_percent = 100;
-      XChangeKeyboardControl
-         (xdisplay, KBBellPitch | KBBellDuration | KBBellPercent, &v);
-
-      /* Ding the bell and make sure it happens now */
-      XBell(xdisplay, 100);
-      XFlush(xdisplay);
-
-      /* Be nice and restore the original values */ 
-      v.bell_pitch = save.bell_pitch;
-      v.bell_duration = save.bell_duration;
-      v.bell_percent = save.bell_percent;
-      XChangeKeyboardControl
-         (xdisplay, KBBellPitch | KBBellDuration | KBBellPercent, &v);
-
-      XCloseDisplay(xdisplay);
+   {  
+      //TJW  implement beep using soundcard
+      extern int tonegen (int tone, float time);
+      tonegen (700, 250);
    }
 
    /* should we blink? */
@@ -469,9 +434,16 @@ void settimer (void)
    char minutes[10], seconds[10];
    static Widget settimerDiag = NULL;
    static Widget timeTFs[2];
-   Widget label1, frame1, timeForm, min_label, sec_label;
-   Widget label2, frame2, optForm, autoResetTB, cwidTB, beepTB, blinkTB;
-   Widget label3, frame3, cwRC, cwSpdScale, cwToneScale;
+   /* Timer */
+   Widget label1;
+   Widget frame1, timeForm, min_label, sec_label;
+   /* Alarms */
+   Widget label2, form2;
+   Widget frame2a, form2a, autoResetTB, blinkTB;
+   Widget frame2b, form2b, alarmRC, cwidTB, beepTB;
+   /* CW ID */
+   Widget label3;
+   Widget frame3, cwRC, cwSpdScale, cwToneScale;
    Widget sep1, okPB, cancelPB;
    Widget label4, label5;
    XmString xms;
@@ -509,6 +481,7 @@ void settimer (void)
       XmNdialogStyle, XmDIALOG_MODELESS,
       XmNverticalSpacing, 10,
       XmNhorizontalSpacing, 10,
+      XmNnoResize, True,
       NULL);
 
    xms = XmStringCreateLocalized ("Timer");
@@ -522,7 +495,7 @@ void settimer (void)
       NULL);
    XmStringFree(xms);
 
-   frame1 = XtVaCreateWidget ("frame1", xmFrameWidgetClass, settimerDiag,
+   frame1 = XtVaCreateManagedWidget ("frame1", xmFrameWidgetClass, settimerDiag,
       XmNshadowType, XmSHADOW_OUT,
       XmNshadowThickness, 3,
       XmNtopAttachment, XmATTACH_WIDGET,
@@ -591,9 +564,8 @@ void settimer (void)
       NULL);
    XmStringFree(xms);
 
-   frame2 = XtVaCreateWidget ("frame1", xmFrameWidgetClass, settimerDiag,
-      XmNshadowType, XmSHADOW_OUT,
-      XmNshadowThickness, 3,
+   form2 = XtVaCreateWidget ("form2", xmFormWidgetClass,
+      settimerDiag,
       XmNtopAttachment, XmATTACH_WIDGET,
       XmNtopWidget, label2,
       XmNleftAttachment, XmATTACH_FORM,
@@ -601,31 +573,77 @@ void settimer (void)
       XmNrightAttachment, XmATTACH_FORM,
       NULL);
 
-   optForm = XtVaCreateWidget ("optForm", xmFormWidgetClass, frame2,
+   frame2a = XtVaCreateManagedWidget ("frame2a", xmFrameWidgetClass,
+      form2,
+      XmNshadowType, XmSHADOW_OUT,
+      XmNshadowThickness, 3,
+      XmNtopAttachment, XmATTACH_FORM,
+      XmNleftAttachment, XmATTACH_FORM,
+      XmNbottomAttachment, XmATTACH_NONE,
+      XmNrightAttachment, XmATTACH_NONE,
+      NULL);
+
+   form2a = XtVaCreateWidget ("form2a", xmFormWidgetClass, frame2a,
       NULL);
 
    xms = XmStringCreateLocalized ("Auto Reset");
    autoResetTB = XtVaCreateManagedWidget ("autoResetTB",
-      xmToggleButtonWidgetClass, optForm,
+      xmToggleButtonWidgetClass, form2a,
       XmNlabelString, xms,
       XmNtopAttachment, XmATTACH_FORM,
       XmNleftAttachment, XmATTACH_FORM,
-      XmNbottomAttachment, XmATTACH_NONE,
+      XmNbottomAttachment, XmATTACH_FORM,
       XmNrightAttachment, XmATTACH_NONE,
       NULL);
    XmStringFree(xms);
    /* sync auoResetTB with autoReset resource */
    XmToggleButtonSetState (autoResetTB, appRes.autoReset, False);
 
-   xms = XmStringCreateLocalized ("CW ID");
-   cwidTB = XtVaCreateManagedWidget ("cwidTB",
-      xmToggleButtonWidgetClass, optForm,
+   xms = XmStringCreateLocalized ("Blink");
+   blinkTB = XtVaCreateManagedWidget ("blinkTB", xmToggleButtonWidgetClass,
+      form2a,
       XmNlabelString, xms,
       XmNtopAttachment, XmATTACH_FORM,
       XmNleftAttachment, XmATTACH_WIDGET,
       XmNleftWidget, autoResetTB,
-      XmNbottomAttachment, XmATTACH_NONE,
-      XmNrightAttachment, XmATTACH_NONE,
+      XmNbottomAttachment, XmATTACH_FORM,
+      XmNrightAttachment, XmATTACH_FORM,
+      NULL);
+   XmStringFree(xms);
+   /* sync blinkTB with blink resource */
+   XmToggleButtonSetState (blinkTB, appRes.blink, False);
+
+   frame2b = XtVaCreateManagedWidget ("frame2b", xmFrameWidgetClass,
+      form2,
+      XmNshadowType, XmSHADOW_OUT,
+      XmNshadowThickness, 3,
+      XmNtopAttachment, XmATTACH_FORM,
+      XmNleftAttachment, XmATTACH_WIDGET,
+      XmNleftWidget, frame2a,
+      XmNbottomAttachment, XmATTACH_OPPOSITE_WIDGET,
+      XmNbottomWidget, frame2a,
+      XmNrightAttachment, XmATTACH_FORM,
+      NULL);
+
+   form2b = XtVaCreateWidget ("form2b", xmFormWidgetClass, frame2b,
+      NULL);
+
+   alarmRC = XtVaCreateManagedWidget ("alarmRC", xmRowColumnWidgetClass,
+      form2b,
+      XmNradioBehavior, True,
+      XmNorientation, XmHORIZONTAL,
+      XmNtopAttachment, XmATTACH_FORM,
+      XmNleftAttachment, XmATTACH_WIDGET,
+      XmNleftWidget, blinkTB,
+      XmNbottomAttachment, XmATTACH_FORM,
+      XmNrightAttachment, XmATTACH_FORM,
+      NULL);
+
+   xms = XmStringCreateLocalized ("CW ID");
+   cwidTB = XtVaCreateManagedWidget ("cwidTB", xmToggleButtonWidgetClass,
+      alarmRC,
+      XmNindicatorType, XmONE_OF_MANY,
+      XmNlabelString, xms,
       NULL);
    XmStringFree(xms);
    /* sync cwidTB with cwid resource */
@@ -633,45 +651,28 @@ void settimer (void)
 
    xms = XmStringCreateLocalized ("Beep");
    beepTB = XtVaCreateManagedWidget ("beepTB", xmToggleButtonWidgetClass,
-      optForm,
+      alarmRC,
+      XmNindicatorType, XmONE_OF_MANY,
       XmNlabelString, xms,
-      XmNtopAttachment, XmATTACH_FORM,
-      XmNleftAttachment, XmATTACH_WIDGET,
-      XmNleftWidget, cwidTB,
-      XmNbottomAttachment, XmATTACH_NONE,
-      XmNrightAttachment, XmATTACH_NONE,
       NULL);
    XmStringFree(xms);
-   /* sync beepTB with beep resource */
+   /* sync beepTB with beep resource in case both are */
    XmToggleButtonSetState (beepTB, appRes.beep, False);
 
-   xms = XmStringCreateLocalized ("Blink");
-   blinkTB = XtVaCreateManagedWidget ("blinkTB", xmToggleButtonWidgetClass,
-      optForm,
-      XmNlabelString, xms,
-      XmNtopAttachment, XmATTACH_FORM,
-      XmNleftAttachment, XmATTACH_WIDGET,
-      XmNleftWidget, beepTB,
-      XmNbottomAttachment, XmATTACH_NONE,
-      XmNrightAttachment, XmATTACH_NONE,
-      NULL);
-   XmStringFree(xms);
-   /* sync blinkTB with blink resource */
-   XmToggleButtonSetState (blinkTB, appRes.blink, False);
 
    xms = XmStringCreateLocalized ("CW ID");
    label3 = XtVaCreateManagedWidget ("label3", xmLabelWidgetClass,
       settimerDiag,
       XmNlabelString, xms,
       XmNtopAttachment, XmATTACH_WIDGET,
-      XmNtopWidget, optForm,
+      XmNtopWidget, frame2a,
       XmNleftAttachment, XmATTACH_FORM,
       XmNbottomAttachment, XmATTACH_NONE,
       XmNrightAttachment, XmATTACH_FORM,
       NULL);
    XmStringFree(xms);
 
-   frame3 = XtVaCreateWidget ("frame3", xmFrameWidgetClass, settimerDiag,
+   frame3 = XtVaCreateManagedWidget ("frame3", xmFrameWidgetClass, settimerDiag,
       XmNshadowType, XmSHADOW_OUT,
       XmNshadowThickness, 3,
       XmNmarginWidth, 5,
@@ -796,11 +797,11 @@ void settimer (void)
 
    /* Manage all the dialog kids */
    XtManageChild (timeForm);
-   XtManageChild (frame1);
-   XtManageChild (optForm);
-   XtManageChild (frame2);
+   XtManageChild (form2a);
+   XtManageChild (alarmRC);
+   XtManageChild (form2b);
+   XtManageChild (form2);
    XtManageChild (cwRC);
-   XtManageChild (frame3);
    XtManageChild (settimerDiag);
 }
 
